@@ -41,7 +41,7 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	: chooser(chooser_store.store),
 	  store(&chooser_store),
 	  list(init, chooser_store.store->children().begin()->get_value(chooser_store.song_list_col)),
-	  controls(init, &list),
+	  controls(init, &list, this),
 	  wr(init),
 	  file_findcurrentsong(_("Find Current Song")),
 	  edit_songinfo(_("Song Info...")),
@@ -50,6 +50,7 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 	  playlist_removesong(_("Remove Song")),
 	  shuffle_button(_("Shuffle")),
 	  repeat_button(_("Repeat")),
+	  search_online(_("Online Search")),
 	  add_uri_box(0),
 	  about_box(0)
 {
@@ -195,17 +196,19 @@ Gnomoradio::MainWindow::MainWindow (Init *init, PlaylistChooserStore &chooser_st
 
 	search.signal_changed().connect(slot(*this, &MainWindow::search_changed));
 	search.signal_activate().connect(slot(*this, &MainWindow::search_activate));
+	search_online.signal_clicked().connect(slot(*this, &MainWindow::search_activate));
 
 	Gtk::HBox *search_hbox = manage(new HBox(false, 2));
 	search_hbox->pack_start(*search_label, PACK_SHRINK);
 	search_hbox->pack_start(search, PACK_SHRINK);
+	search_hbox->pack_start(search_online, PACK_SHRINK);
 
 	top.pack_start(controls);
 	top.pack_start(*search_hbox, PACK_SHRINK, 8);
 
 	hpaned.pack1(left, FILL);
 	hpaned.pack2(list, EXPAND);
-	hpaned.set_border_width(10);
+	hpaned.set_border_width(8);
 
 	chooser.set_headers_visible(false);
 	chooser.append_column(_("Icon"), chooser_store.icon_col);
@@ -301,7 +304,13 @@ bool Gnomoradio::MainWindow::on_chooser_clicked (GdkEventButton *event)
 void Gnomoradio::MainWindow::search_changed ()
 {
 	if (search.get_text().size() == 0) {
-		list.set(store->store->children().begin()->get_value(store->song_list_col));
+		if (chooser.get_selection()->get_selected())
+			list.set(chooser.get_selection()->get_selected()->get_value(store->song_list_col));
+		else
+			list.set(store->store->children().begin()->get_value(store->song_list_col));
+
+		playlist_settings.set_sensitive(true);
+		playlist_remove.set_sensitive(list.current_list().destroyable());
 		return;
 	}
 
@@ -335,6 +344,8 @@ void Gnomoradio::MainWindow::search_changed ()
 		search_list.reset(new SongListSearch(query.write_to_string()));
 
 	list.set(*search_list);
+	playlist_settings.set_sensitive(false);
+	playlist_remove.set_sensitive(false);
 }
 
 void Gnomoradio::MainWindow::search_activate ()
@@ -360,13 +371,15 @@ void Gnomoradio::MainWindow::remove_playlist (Wraporadio::SongList songlist)
 	dialog.add_button(_("Cancel"), 0);
 	
 	Label *question = manage(new Label(_("Really remove playlist: ") + playlist_title + _("?")));
-	dialog.get_vbox()->pack_start(*question, PACK_SHRINK, 10);
+	dialog.get_vbox()->pack_start(*question, PACK_SHRINK, 8);
 	question->show();
 	
 	int response_yes = dialog.run();
 	
 	if (response_yes) {
 		list.set(store->store->children().begin()->get_value(store->song_list_col));
+		playlist_settings.set_sensitive(true);
+		playlist_remove.set_sensitive(list.current_list().destroyable());
 		songlist.destroy();
 	}
 }
@@ -375,6 +388,8 @@ void Gnomoradio::MainWindow::on_shuffle_clicked ()
 {
 	list.base_list().set_shuffle(shuffle_button.get_active());
 	list.set(list.base_list());
+	playlist_settings.set_sensitive(true);
+	playlist_remove.set_sensitive(list.current_list().destroyable());
 }
 
 void Gnomoradio::MainWindow::on_repeat_clicked ()
@@ -399,12 +414,15 @@ void Gnomoradio::MainWindow::on_chooser_change ()
 	edit_songinfo.set_sensitive(false);
 	playlist_removesong.set_sensitive(false);
 	if (chooser.get_selection()->get_selected()) {
-		playlist_remove.set_sensitive(chooser.get_selection()->get_selected()->get_value(store->song_list_col).destroyable());
-		playlist_settings.set_sensitive(true);
 		list.set(chooser.get_selection()->get_selected()->get_value(store->song_list_col));
+		playlist_remove.set_sensitive(list.current_list().destroyable());
+		playlist_settings.set_sensitive(true);
 	} else {
 		playlist_remove.set_sensitive(false);
 	}
+
+	if (search.get_text().size() != 0)
+		search.set_text("");
 }
 
 void Gnomoradio::MainWindow::set_edit_song_info_sensitivity ()
@@ -613,4 +631,6 @@ void Gnomoradio::MainWindow::find_current_song ()
 {
 	list.set(wr->player()->get_song_list());
 	list.scroll_to_song(wr->player()->get_song_list()->get_current_song());
+	playlist_settings.set_sensitive(true);
+	playlist_remove.set_sensitive(list.current_list().destroyable());
 }
