@@ -637,8 +637,8 @@ void Rainbow::HubClient::download_success (Resource *r)
 {
 	r->prepared = true;
 	r->downloading = false;
-	check_allocated_size(r);
 	r->signal_download_done(true);
+	check_allocated_size(r);
 }
 
 void Rainbow::HubClient::file_download_done_callback (bool success, Resource *r)
@@ -704,6 +704,9 @@ void Rainbow::HubClient::review_cache_size ()
 
 void Rainbow::HubClient::set_cache_size (unsigned int megabytes)
 {
+	if (megabytes < 30)
+		megabytes = 30; // there has to be a bottom limit
+
 	cache_size = megabytes;
 	review_cache_size();
 }
