@@ -138,7 +138,8 @@ Roboradio::State::State ()
 	  conserve_privacy(true),
 	  loaded_song_paths(false),
 	  state_file_already_exists(false),
-	  lib(0)
+	  lib(0),
+	  cache_size(0)
 {
 	tree.reset(new xmlpp::DomParser);
 
